@@ -1,13 +1,13 @@
 from typing import Optional
 
-from avionix.kubernetes_objects.base_objects import HelmYaml
+from avionix.kube.base_objects import HelmYaml
 
 
 class ChartMaintainer(HelmYaml):
     """
-    name: The maintainers name (required for each maintainer)
-    email: The maintainers email (optional for each maintainer)
-    url: A URL for the maintainer (optional for each maintainer)
+    :param name: The maintainers name (required for each maintainer)
+    :param email: The maintainers email (optional for each maintainer)
+    :param url: A URL for the maintainer (optional for each maintainer)
     """
 
     def __init__(
